<?php

namespace Edulab\Standard\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Edulab\Standard\Events\DivisionAction as DivisionActionEvent;
use Edulab\Standard\Notifications\DivisionAction as DivisionActionNotification;
use Litepie\Actions\Concerns\AsAction;

class DivisionAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the DivisionActionEvent.
     *
     * @param   DivisionActionEvent  $event
     * @return mixed
     */
    public function handle(DivisionActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $division.
     *
     * @param   DivisionActionEvent  $event
     * @return void
     */
    public function create(DivisionActionEvent $event)
    {
        $client = $event->division->client;
        Notification::send($client, new DivisionActionNotification($event));
    }

    /**
     * Handle the DivisionActionEvent as a listener.
     *
     * @param   DivisionActionEvent  $event
     * @return mixed
     */
    public function asListener(DivisionActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   DivisionActionEvent  $event
     * @return bool
     */
    private function isAllowed(DivisionActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
