<?php

namespace Edulab\Standard\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Edulab\Standard\Events\StandardAction as StandardActionEvent;
use Edulab\Standard\Notifications\StandardAction as StandardActionNotification;
use Litepie\Actions\Concerns\AsAction;

class StandardAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the StandardActionEvent.
     *
     * @param   StandardActionEvent  $event
     * @return mixed
     */
    public function handle(StandardActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $standard.
     *
     * @param   StandardActionEvent  $event
     * @return void
     */
    public function create(StandardActionEvent $event)
    {
        $client = $event->standard->client;
        Notification::send($client, new StandardActionNotification($event));
    }

    /**
     * Handle the StandardActionEvent as a listener.
     *
     * @param   StandardActionEvent  $event
     * @return mixed
     */
    public function asListener(StandardActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   StandardActionEvent  $event
     * @return bool
     */
    private function isAllowed(StandardActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
