<?php

namespace Edulab\Standard\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Edulab\Standard\Events\SubjectAction as SubjectActionEvent;
use Edulab\Standard\Notifications\SubjectAction as SubjectActionNotification;
use Litepie\Actions\Concerns\AsAction;

class SubjectAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the SubjectActionEvent.
     *
     * @param   SubjectActionEvent  $event
     * @return mixed
     */
    public function handle(SubjectActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $subject.
     *
     * @param   SubjectActionEvent  $event
     * @return void
     */
    public function create(SubjectActionEvent $event)
    {
        $client = $event->subject->client;
        Notification::send($client, new SubjectActionNotification($event));
    }

    /**
     * Handle the SubjectActionEvent as a listener.
     *
     * @param   SubjectActionEvent  $event
     * @return mixed
     */
    public function asListener(SubjectActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   SubjectActionEvent  $event
     * @return bool
     */
    private function isAllowed(SubjectActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
