<?php

namespace Edulab\Standard\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Edulab\Standard\Events\TimetableAction as TimetableActionEvent;
use Edulab\Standard\Notifications\TimetableAction as TimetableActionNotification;
use Litepie\Actions\Concerns\AsAction;

class TimetableAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the TimetableActionEvent.
     *
     * @param   TimetableActionEvent  $event
     * @return mixed
     */
    public function handle(TimetableActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $timetable.
     *
     * @param   TimetableActionEvent  $event
     * @return void
     */
    public function create(TimetableActionEvent $event)
    {
        $client = $event->timetable->client;
        Notification::send($client, new TimetableActionNotification($event));
    }

    /**
     * Handle the TimetableActionEvent as a listener.
     *
     * @param   TimetableActionEvent  $event
     * @return mixed
     */
    public function asListener(TimetableActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   TimetableActionEvent  $event
     * @return bool
     */
    private function isAllowed(TimetableActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
