<?php

namespace Edulab\Standard\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Edulab\Standard\Models\Division;

class DivisionPolicy
{


    /**
     * Determine if the given user can view the division.
     *
     * @param Authenticatable $user
     * @param Division $division
     *
     * @return bool
     */
    public function view(Authenticatable $user, Division $division)
    {
        if ($authUser->canDo('standard.division.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $division->is_owner;
    }

    /**
     * Determine if the given user can create a division.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('standard.division.create');
    }

    /**
     * Determine if the given user can update the given division.
     *
     * @param Authenticatable $user
     * @param Division $division
     *
     * @return bool
     */
    public function update(Authenticatable $user, Division $division)
    {
        if ($user->canDo('standard.division.edit') && $user->isAdmin()) {
            return true;
        }

        return $division->is_owner;
    }

    /**
     * Determine if the given user can delete the given division.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Division $division)
    {
        return $division->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
