<?php

namespace Edulab\Standard\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Edulab\Standard\Models\Standard;

class StandardPolicy
{


    /**
     * Determine if the given user can view the standard.
     *
     * @param Authenticatable $user
     * @param Standard $standard
     *
     * @return bool
     */
    public function view(Authenticatable $user, Standard $standard)
    {
        if ($authUser->canDo('standard.standard.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $standard->is_owner;
    }

    /**
     * Determine if the given user can create a standard.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('standard.standard.create');
    }

    /**
     * Determine if the given user can update the given standard.
     *
     * @param Authenticatable $user
     * @param Standard $standard
     *
     * @return bool
     */
    public function update(Authenticatable $user, Standard $standard)
    {
        if ($user->canDo('standard.standard.edit') && $user->isAdmin()) {
            return true;
        }

        return $standard->is_owner;
    }

    /**
     * Determine if the given user can delete the given standard.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Standard $standard)
    {
        return $standard->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
