<?php

namespace Edulab\Standard\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Edulab\Standard\Models\Subject;

class SubjectPolicy
{


    /**
     * Determine if the given user can view the subject.
     *
     * @param Authenticatable $user
     * @param Subject $subject
     *
     * @return bool
     */
    public function view(Authenticatable $user, Subject $subject)
    {
        if ($authUser->canDo('standard.subject.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $subject->is_owner;
    }

    /**
     * Determine if the given user can create a subject.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('standard.subject.create');
    }

    /**
     * Determine if the given user can update the given subject.
     *
     * @param Authenticatable $user
     * @param Subject $subject
     *
     * @return bool
     */
    public function update(Authenticatable $user, Subject $subject)
    {
        if ($user->canDo('standard.subject.edit') && $user->isAdmin()) {
            return true;
        }

        return $subject->is_owner;
    }

    /**
     * Determine if the given user can delete the given subject.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Subject $subject)
    {
        return $subject->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
