<?php

namespace Edulab\Standard\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Edulab\Standard\Models\Timetable;

class TimetablePolicy
{


    /**
     * Determine if the given user can view the timetable.
     *
     * @param Authenticatable $user
     * @param Timetable $timetable
     *
     * @return bool
     */
    public function view(Authenticatable $user, Timetable $timetable)
    {
        if ($authUser->canDo('standard.timetable.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $timetable->is_owner;
    }

    /**
     * Determine if the given user can create a timetable.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('standard.timetable.create');
    }

    /**
     * Determine if the given user can update the given timetable.
     *
     * @param Authenticatable $user
     * @param Timetable $timetable
     *
     * @return bool
     */
    public function update(Authenticatable $user, Timetable $timetable)
    {
        if ($user->canDo('standard.timetable.edit') && $user->isAdmin()) {
            return true;
        }

        return $timetable->is_owner;
    }

    /**
     * Determine if the given user can delete the given timetable.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Timetable $timetable)
    {
        return $timetable->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
