<?php

namespace Edulab\Standard\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Edulab\Standard\Models\Standard;
use Edulab\Standard\Models\Division;
use Edulab\Standard\Models\Subject;
use Edulab\Standard\Models\Timetable;

use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Edulab\Standard\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/standard/standard/*')) {
            Route::bind('standard', function ($standard) {
                return Standard::findorNew($standard);
            });
        }
        if (Request::is('*/standard/division/*')) {
            Route::bind('division', function ($division) {
                return Division::findorNew($division);
            });
        }
        if (Request::is('*/standard/subject/*')) {
            Route::bind('subject', function ($subject) {
                return Subject::findorNew($subject);
            });
        }
        if (Request::is('*/standard/timetable/*')) {
            Route::bind('timetable', function ($timetable) {
                return Timetable::findorNew($timetable);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => 'api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
