<?php

namespace Edulab\Standard\Providers;

use Illuminate\Support\ServiceProvider;
use Edulab\Standard\Standards;

class StandardServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'standard');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'standard');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();

        $this->app->register(\Edulab\Standard\Providers\AuthServiceProvider::class);
        $this->app->register(\Edulab\Standard\Providers\RouteServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('edulab.standard', function($app)
        {
            return $this->app->make(Standard::class);
        });
    }

    /**
     * Merges user's and standard's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'edulab.standard'
        );
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/standard.php', 'edulab.standard.standard'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/division.php', 'edulab.standard.division'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/subject.php', 'edulab.standard.subject'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/timetable.php', 'edulab.standard.timetable'
        );
    }


    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['edulab.standard'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('edulab/standard')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/standard')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/standard')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
